@@ -101,8 +101,9 @@ class Service(object):
     command = None
     shell_command = None
     shell_links = None
+    shell_volumes = None
     
-    def __init__(self, name, image, volumes={}, env={}, links=[], ports=[], command=None, shell_command=None, shell_links=None, registry_login=None):
+    def __init__(self, name, image, volumes={}, env={}, links=[], ports=[], command=None, shell_command=None, shell_links=None, shell_volumes=False, registry_login=None):
         self.name = name
         self.image = image
         self.volumes = volumes
@@ -112,6 +113,7 @@ class Service(object):
         self.command = command
         self.shell_command = shell_command
         self.shell_links = shell_links
+        self.shell_volumes = shell_volumes
         self.registry_login = registry_login
     
     @cmd
@@ -123,7 +125,8 @@ class Service(object):
     
     @cmd
     def stop(self):
-        self.project.run("docker stop %s" % self.container_name)
+        if self.exists() and self.is_running():
+            self.project.run("docker stop %s" % self.container_name)
     
     @cmd
     def restart(self):
@@ -134,7 +137,8 @@ class Service(object):
     
     @cmd
     def rm(self):
-        self.project.run("docker rm %s" % self.container_name)
+        if self.exists():
+            self.project.run("docker rm %s" % self.container_name)
     
     @cmd
     @click.option("--follow/--no-follow", "-f", default=False)
@@ -151,6 +155,8 @@ class Service(object):
         arguments = ["docker run --rm -i -t"]
         arguments.append("--name=%s_shell_%i" % (self.container_name, int(time.time()*1000)))
         arguments.append(self._run_link_arguments(self.shell_links))
+        if self.shell_volumes:
+            arguments.append(self._run_volume_arguments())
         arguments.append(self.image)
         arguments.append(self.shell_command)
         self.project.run_ssh(" ".join(arguments))
@@ -175,7 +181,7 @@ class Service(object):
     @cmd
     @click.option("--interactive", "-i", default=True, is_flag=True)
     @click.option("--terminal", "-t", default=True, is_flag=True)
-    @click.option("--volumes", default=False, is_flag=True)
+    @click.option("--volumes", default=True, is_flag=True)
     @click.argument("command")
     def run(self, command, interactive=True, terminal=True, container_name_suffix="cmd", volumes=False):
         args = ["docker run --rm"]
@@ -200,7 +206,7 @@ class Service(object):
             'docker inspect -f "{{ .NetworkSettings.IPAddress }}" %s' % self.container_name,
             quiet=True,
         )
-        return bool(response)
+        return bool(response) and ("Error" not in response)
     
     def exists(self):
         response = self.project.run(
